pub struct HighlightingHtmlRendererOptions {
pub theme: &'static str,
pub mode: HighlightingMode,
pub theme_set: Option<Rc<ThemeSet>>,
}Expand description
Options for the HighlightingHtmlRenderer.
Fields
theme: &'static strThe name of the syntax highlighting theme to use.
This value is only used if the mode is set to HighlightingMode::Attribute. If the theme
is not found, it falls back to “InspiredGitHub”.
mode: HighlightingModeThe mode to use for syntax highlighting. This determines how the HTML output is structured.
theme_set: Option<Rc<ThemeSet>>An optional ThemeSet to use for syntax highlighting. If not provided, the default themes
will be used.